export default Metadatas;

import fs from 'node:fs';
import path from 'node:path';
import Posts from './PostList';
import Load from './LoadPost';

import { dev } from '$app/environment';

async function Metadatas() {

    const cache_dir = '/tmp/day.moris.blog/';
    const cache_file = `${cache_dir}metadata.json`;

    async function build() {
        const posts = await Posts();

        const metadataList = await Promise.all(posts.map(async (file)=>{
            const postId = path.basename(file, '.md')
            const metadata = (await Load(postId)).metadata
            return {postId, metadata}
        }))

        const sorted = metadataList
            .sort((a,b)=>{
                return b.metadata.date.getTime() - a.metadata.date.getTime()
            })
            .filter((m)=> dev||m.metadata.published)

        return sorted
    }

    async function makeCache() {
        let data = await build()
        let cache_data = {
            cached_time: Date.now(),
            dev,
            data
        }

        if (!fs.existsSync(cache_dir)) {
            fs.mkdirSync(cache_dir), {recursive: true}
        }

        fs.writeFileSync(cache_file, JSON.stringify(cache_data, null, 2), 'utf8')
        return data
    }


    if (fs.existsSync(cache_file)) {
        const cache = JSON.parse(fs.readFileSync(cache_file, 'utf8'), (key,value)=>{
            if(key=='date'){
                return (new Date(value));
            }
            return value
        })

        if (Boolean(cache.dev)!=dev || Date.now()-cache.cached_time>5*60000) {
            const data = await makeCache()
            return data
        } else {
            return cache.data
        }
    } else {
        const data = await makeCache()
        return data
    }
}